@@ -335,7 +335,7 @@ impl<O: Offset> MutableBinaryArray<O> {
         extend_from_trusted_len_iter(
             &mut self.offsets,
             &mut self.values,
-            &mut self.validity.as_mut().unwrap(),
+            self.validity.as_mut().unwrap(),
             iterator,
         );
 
