@@ -152,11 +152,10 @@ impl<O: Offset> MutableUtf8Array<O> {
     }
 
     fn init_validity(&mut self) {
-        self.validity = Some(MutableBitmap::from_trusted_len_iter(
-            std::iter::repeat(true)
-                .take(self.len() - 1)
-                .chain(std::iter::once(false)),
-        ))
+        let mut validity = MutableBitmap::with_capacity(self.offsets.capacity());
+        validity.extend_constant(self.len(), true);
+        validity.set(self.len() - 1, false);
+        self.validity = Some(validity);
     }
 
     /// Converts itself into an [`Array`].
@@ -306,7 +305,7 @@ impl<O: Offset> MutableUtf8Array<O> {
         extend_from_trusted_len_iter(
             &mut self.offsets,
             &mut self.values,
-            &mut self.validity.as_mut().unwrap(),
+            self.validity.as_mut().unwrap(),
             iterator,
         );
 
