@@ -108,14 +108,32 @@ impl Bitmap {
 
     /// Slices `self`, offseting by `offset` and truncating up to `length` bits.
     /// # Panic
-    /// Panics iff `self.offset + offset + length <= self.bytes.len() * 8`, i.e. if the offset and `length`
+    /// Panics iff `self.offset + offset + length >= self.bytes.len() * 8`, i.e. if the offset and `length`
     /// exceeds the allocated capacity of `self`.
     #[inline]
-    pub fn slice(mut self, offset: usize, length: usize) -> Self {
+    pub fn slice(self, offset: usize, length: usize) -> Self {
         assert!(offset + length <= self.length);
+        unsafe { self.slice_unchecked(offset, length) }
+    }
+
+    /// Slices `self`, offseting by `offset` and truncating up to `length` bits.
+    /// # Safety
+    /// The caller must ensure that `self.offset + offset + length <= self.len()`
+    #[inline]
+    pub unsafe fn slice_unchecked(mut self, offset: usize, length: usize) -> Self {
+        // count the smallest chunk
+        if length < self.length / 2 {
+            // count the null values in the slice
+            self.null_count = count_zeros(&self.bytes, offset, length);
+        } else {
+            // subtract the null count of the chunks we slice off
+            let start_end = self.offset + offset + length;
+            let head_count = count_zeros(&self.bytes, self.offset, offset);
+            let tail_count = count_zeros(&self.bytes, start_end, self.length - length - offset);
+            self.null_count -= head_count + tail_count;
+        }
         self.offset += offset;
         self.length = length;
-        self.null_count = count_zeros(&self.bytes, self.offset, self.length);
         self
     }
 
