@@ -64,9 +64,11 @@ pub fn sub(lhs: &PrimitiveArray<i128>, rhs: &PrimitiveArray<i128>) -> Result<Pri
                 let op = move |a, b| {
                     let res: i128 = a - b;
 
-                    if res.abs() > max_value(*lhs_p) {
-                        panic!("Overflow in subtract presented for precision {}", lhs_p);
-                    }
+                    assert!(
+                        !(res.abs() > max_value(*lhs_p)),
+                        "Overflow in subtract presented for precision {}",
+                        lhs_p
+                    );
 
                     res
                 };
