@@ -1,18 +1,19 @@
 use std::collections::VecDeque;
 use std::io::{Read, Seek};
 
+use arrow_format::ipc;
+
 use crate::array::BooleanArray;
 use crate::datatypes::DataType;
 use crate::error::Result;
 
-use super::super::super::gen;
 use super::super::deserialize::Node;
 use super::super::read_basic::*;
 
 pub fn read_boolean<R: Read + Seek>(
     field_nodes: &mut VecDeque<Node>,
     data_type: DataType,
-    buffers: &mut VecDeque<&gen::Schema::Buffer>,
+    buffers: &mut VecDeque<&ipc::Schema::Buffer>,
     reader: &mut R,
     block_offset: u64,
     is_little_endian: bool,
@@ -42,7 +43,7 @@ pub fn read_boolean<R: Read + Seek>(
 
 pub fn skip_boolean(
     field_nodes: &mut VecDeque<Node>,
-    buffers: &mut VecDeque<&gen::Schema::Buffer>,
+    buffers: &mut VecDeque<&ipc::Schema::Buffer>,
 ) {
     let _ = field_nodes.pop_front().unwrap();
 
