@@ -2,16 +2,17 @@ use std::collections::VecDeque;
 use std::convert::TryInto;
 use std::io::{Read, Seek};
 
+use arrow_format::ipc;
+
 use crate::array::{DictionaryArray, DictionaryKey};
 use crate::error::Result;
 
-use super::super::super::gen;
 use super::super::deserialize::Node;
 use super::{read_primitive, skip_primitive};
 
 pub fn read_dictionary<T: DictionaryKey, R: Read + Seek>(
     field_nodes: &mut VecDeque<Node>,
-    buffers: &mut VecDeque<&gen::Schema::Buffer>,
+    buffers: &mut VecDeque<&ipc::Schema::Buffer>,
     reader: &mut R,
     block_offset: u64,
     is_little_endian: bool,
@@ -36,7 +37,7 @@ where
 
 pub fn skip_dictionary(
     field_nodes: &mut VecDeque<Node>,
-    buffers: &mut VecDeque<&gen::Schema::Buffer>,
+    buffers: &mut VecDeque<&ipc::Schema::Buffer>,
 ) {
     skip_primitive(field_nodes, buffers)
 }
