@@ -1,23 +1,23 @@
 use std::collections::VecDeque;
 use std::io::{Read, Seek};
 
+use arrow_format::ipc;
+
 use crate::array::FixedSizeBinaryArray;
 use crate::datatypes::DataType;
 use crate::error::Result;
-use crate::io::ipc::gen::Message::BodyCompression;
 
-use super::super::super::gen;
 use super::super::deserialize::Node;
 use super::super::read_basic::*;
 
 pub fn read_fixed_size_binary<R: Read + Seek>(
     field_nodes: &mut VecDeque<Node>,
     data_type: DataType,
-    buffers: &mut VecDeque<&gen::Schema::Buffer>,
+    buffers: &mut VecDeque<&ipc::Schema::Buffer>,
     reader: &mut R,
     block_offset: u64,
     is_little_endian: bool,
-    compression: Option<BodyCompression>,
+    compression: Option<ipc::Message::BodyCompression>,
 ) -> Result<FixedSizeBinaryArray> {
     let field_node = field_nodes.pop_front().unwrap().0;
 
@@ -46,7 +46,7 @@ pub fn read_fixed_size_binary<R: Read + Seek>(
 
 pub fn skip_fixed_size_binary(
     field_nodes: &mut VecDeque<Node>,
-    buffers: &mut VecDeque<&gen::Schema::Buffer>,
+    buffers: &mut VecDeque<&ipc::Schema::Buffer>,
 ) {
     let _ = field_nodes.pop_front().unwrap();
 
