@@ -18,15 +18,16 @@
 use std::io::Read;
 use std::sync::Arc;
 
-use gen::Schema::MetadataVersion;
+use arrow_format::ipc;
+use arrow_format::ipc::Schema::MetadataVersion;
 
 use crate::array::*;
 use crate::datatypes::Schema;
 use crate::error::{ArrowError, Result};
 use crate::record_batch::RecordBatch;
 
+use super::super::convert;
 use super::super::CONTINUATION_MARKER;
-use super::super::{convert, gen};
 use super::common::*;
 
 type ArrayRef = Arc<dyn Array>;
@@ -59,11 +60,11 @@ pub fn read_stream_metadata<R: Read>(reader: &mut R) -> Result<StreamMetadata> {
     let mut meta_buffer = vec![0; meta_len as usize];
     reader.read_exact(&mut meta_buffer)?;
 
-    let message = gen::Message::root_as_message(meta_buffer.as_slice())
+    let message = ipc::Message::root_as_message(meta_buffer.as_slice())
         .map_err(|err| ArrowError::Ipc(format!("Unable to get root as message: {:?}", err)))?;
     let version = message.version();
     // message header is a Schema, so read it
-    let ipc_schema: gen::Schema::Schema = message
+    let ipc_schema: ipc::Schema::Schema = message
         .header_as_schema()
         .ok_or_else(|| ArrowError::Ipc("Unable to read IPC message as schema".to_string()))?;
     let (schema, is_little_endian) = convert::fb_to_schema(ipc_schema);
@@ -76,12 +77,28 @@ pub fn read_stream_metadata<R: Read>(reader: &mut R) -> Result<StreamMetadata> {
     })
 }
 
+/// Encodes the stream's status after each read.
+///
+/// A stream is an iterator, and an iterator returns `Option<Item>`. The `Item`
+/// type in the [`StreamReader`] case is `StreamState`, which means that an Arrow
+/// stream may yield one of three values: (1) `None`, which signals that the stream
+/// is done; (2) `Some(StreamState::Some(RecordBatch))`, which signals that there was
+/// data waiting in the stream and we read it; and finally (3)
+/// `Some(StreamState::Waiting)`, which means that the stream is still "live", it
+/// just doesn't hold any data right now.
 pub enum StreamState {
+    /// A live stream without data
     Waiting,
+    /// Next item in the stream
     Some(RecordBatch),
 }
 
 impl StreamState {
+    /// Return the data inside this wrapper.
+    ///
+    /// # Panics
+    ///
+    /// If the `StreamState` was `Waiting`.
     pub fn unwrap(self) -> RecordBatch {
         if let StreamState::Some(batch) = self {
             batch
@@ -91,7 +108,8 @@ impl StreamState {
     }
 }
 
-/// Reads the next item
+/// Reads the next item, yielding `None` if the stream is done,
+/// and a [`StreamState`] otherwise.
 pub fn read_next<R: Read>(
     reader: &mut R,
     metadata: &StreamMetadata,
@@ -132,14 +150,14 @@ pub fn read_next<R: Read>(
     reader.read_exact(&mut meta_buffer)?;
 
     let vecs = &meta_buffer.to_vec();
-    let message = gen::Message::root_as_message(vecs)
+    let message = ipc::Message::root_as_message(vecs)
         .map_err(|err| ArrowError::Ipc(format!("Unable to get root as message: {:?}", err)))?;
 
     match message.header_type() {
-        gen::Message::MessageHeader::Schema => Err(ArrowError::Ipc(
+        ipc::Message::MessageHeader::Schema => Err(ArrowError::Ipc(
             "Not expecting a schema when messages are read".to_string(),
         )),
-        gen::Message::MessageHeader::RecordBatch => {
+        ipc::Message::MessageHeader::RecordBatch => {
             let batch = message.header_as_record_batch().ok_or_else(|| {
                 ArrowError::Ipc("Unable to read IPC message as record batch".to_string())
             })?;
@@ -161,7 +179,7 @@ pub fn read_next<R: Read>(
             )
             .map(|x| Some(StreamState::Some(x)))
         }
-        gen::Message::MessageHeader::DictionaryBatch => {
+        ipc::Message::MessageHeader::DictionaryBatch => {
             let batch = message.header_as_dictionary_batch().ok_or_else(|| {
                 ArrowError::Ipc("Unable to read IPC message as dictionary batch".to_string())
             })?;
@@ -183,7 +201,7 @@ pub fn read_next<R: Read>(
             // read the next message until we encounter a RecordBatch
             read_next(reader, metadata, dictionaries_by_field)
         }
-        gen::Message::MessageHeader::NONE => Ok(Some(StreamState::Waiting)),
+        ipc::Message::MessageHeader::NONE => Ok(Some(StreamState::Waiting)),
         t => Err(ArrowError::Ipc(format!(
             "Reading types other than record batches not yet supported, unable to read {:?} ",
             t
@@ -191,7 +209,12 @@ pub fn read_next<R: Read>(
     }
 }
 
-/// Arrow Stream reader
+/// Arrow Stream reader.
+///
+/// An [`Iterator`] over an Arrow stream that yields a result of [`StreamState`]s.
+/// This is the recommended way to read an arrow stream (by iterating over its data).
+///
+/// For a more thorough walkthrough consult [this example](https://github.com/jorgecarleitao/arrow2/tree/main/examples/ipc_pyarrow).
 pub struct StreamReader<R: Read> {
     reader: R,
     metadata: StreamMetadata,
