@@ -15,18 +15,17 @@
 // specific language governing permissions and limitations
 // under the License.
 
+use arrow_format::ipc::{Message, Schema};
+
 use crate::{
     array::*,
     bitmap::Bitmap,
     datatypes::{DataType, PhysicalType},
-    endianess::is_native_little_endian,
-    io::ipc::gen::Message,
     trusted_len::TrustedLen,
     types::NativeType,
 };
 
-use crate::io::ipc::gen::Schema;
-
+use super::super::endianess::is_native_little_endian;
 use super::common::pad_to_8;
 
 fn _write_primitive<T: NativeType>(
