@@ -12,8 +12,6 @@ mod utils;
 
 pub mod stream;
 
-use std::sync::Arc;
-
 use crate::array::*;
 use crate::bitmap::Bitmap;
 use crate::buffer::{Buffer, MutableBuffer};
@@ -24,13 +22,19 @@ use crate::io::parquet::write::levels::NestedInfo;
 use crate::types::days_ms;
 use crate::types::NativeType;
 
+use parquet2::page::DataPage;
 pub use parquet2::{
     compression::Compression,
     encoding::Encoding,
+    fallible_streaming_iterator,
     metadata::{ColumnDescriptor, KeyValue, SchemaDescriptor},
-    page::{CompressedDataPage, CompressedPage},
+    page::{CompressedDataPage, CompressedPage, EncodedPage},
     schema::types::ParquetType,
-    write::{write_file as parquet_write_file, DynIter, RowGroupIter, Version, WriteOptions},
+    write::{
+        compress, write_file as parquet_write_file, Compressor, DynIter, DynStreamingIterator,
+        RowGroupIter, Version, WriteOptions,
+    },
+    FallibleStreamingIterator,
 };
 pub use record_batch::RowGroupIterator;
 use schema::schema_to_metadata_key;
@@ -104,13 +108,13 @@ pub fn can_encode(data_type: &DataType, encoding: Encoding) -> bool {
     )
 }
 
-/// Returns an iterator of compressed pages,
+/// Returns an iterator of [`EncodedPage`].
 pub fn array_to_pages(
-    array: Arc<dyn Array>,
+    array: &dyn Array,
     descriptor: ColumnDescriptor,
     options: WriteOptions,
     encoding: Encoding,
-) -> Result<DynIter<'static, Result<CompressedPage>>> {
+) -> Result<DynIter<'static, Result<EncodedPage>>> {
     match array.data_type() {
         DataType::Dictionary(key_type, _) => {
             with_match_dictionary_key_type!(key_type.as_ref(), |$T| {
@@ -122,7 +126,7 @@ pub fn array_to_pages(
                 )
             })
         }
-        _ => array_to_page(array.as_ref(), descriptor, options, encoding)
+        _ => array_to_page(array, descriptor, options, encoding)
             .map(|page| DynIter::new(std::iter::once(Ok(page)))),
     }
 }
@@ -133,7 +137,7 @@ pub fn array_to_page(
     descriptor: ColumnDescriptor,
     options: WriteOptions,
     encoding: Encoding,
-) -> Result<CompressedPage> {
+) -> Result<EncodedPage> {
     let data_type = array.data_type();
     if !can_encode(data_type, encoding) {
         return Err(ArrowError::InvalidArgumentError(format!(
@@ -298,9 +302,7 @@ pub fn array_to_page(
                 primitive::array_to_page::<i64, i64>(&array, options, descriptor)
             } else {
                 let size = decimal_length_from_precision(precision);
-
-                let mut values = MutableBuffer::<u8>::new(); // todo: this can be estimated
-
+                let mut values = MutableBuffer::<u8>::with_capacity(size * array.len());
                 array.values().iter().for_each(|x| {
                     let bytes = &x.to_be_bytes()[16 - size..];
                     values.extend_from_slice(bytes)
@@ -321,7 +323,7 @@ pub fn array_to_page(
             other
         ))),
     }
-    .map(CompressedPage::Data)
+    .map(EncodedPage::Data)
 }
 
 macro_rules! dyn_nested_prim {
@@ -343,7 +345,7 @@ fn list_array_to_page<O: Offset>(
     values: &dyn Array,
     descriptor: ColumnDescriptor,
     options: WriteOptions,
-) -> Result<CompressedDataPage> {
+) -> Result<DataPage> {
     use DataType::*;
     let is_optional = is_type_nullable(descriptor.type_());
     let nested = NestedInfo::new(offsets, validity, is_optional);
@@ -422,7 +424,7 @@ fn nested_array_to_page(
     array: &dyn Array,
     descriptor: ColumnDescriptor,
     options: WriteOptions,
-) -> Result<CompressedDataPage> {
+) -> Result<DataPage> {
     match array.data_type() {
         DataType::List(_) => {
             let array = array.as_any().downcast_ref::<ListArray<i32>>().unwrap();
